@@ -4,10 +4,11 @@ from .constants import *
 from urllib.parse import urljoin
 
 class Api(object):
-    def __init__(self, header_options, base_url=DEFAULT_SUPERGOOD_BASE_URL):
+    def __init__(self, header_options, base_url=DEFAULT_SUPERGOOD_BASE_URL, config=None):
         self.base_url = base_url
         self.header_options = header_options
         self.config_fetch_url = urljoin(self.base_url, 'api/config')
+        self.config = config
 
     def set_logger(self, logger):
         self.log = logger
@@ -19,7 +20,6 @@ class Api(object):
         self.error_sink_url = urljoin(self.base_url, endpoint)
 
     def post_events(self, payload):
-        print('Not Mocked', payload)
         response = requests.post(self.event_sink_url, json=payload, headers=self.header_options)
         if(response.status_code == 401):
             raise Exception(ERRORS['UNAUTHORIZED'])
@@ -40,10 +40,13 @@ class Api(object):
             self.log.warning(f'Failed to report error to {self.error_sink_url}')
 
     def fetch_config(self):
-        response = requests.get(self.config_fetch_url, headers=self.header_options)
-        if(response.status_code == 401):
-            raise Exception(ERRORS['UNAUTHORIZED'])
-        if(response.status_code != 200):
-            raise Exception(ERRORS['FETCHING_CONFIG'])
-        return response.json()
+        if(self.config):
+            return self.config
+        else:
+            response = requests.get(self.config_fetch_url, headers=self.header_options)
+            if(response.status_code == 401):
+                raise Exception(ERRORS['UNAUTHORIZED'])
+            if(response.status_code != 200):
+                raise Exception(ERRORS['FETCHING_CONFIG'])
+            return response.json()
 
